==> haskell-x509-store-1.6.2-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-D1ITMi7mZVrH6DgsUfztV9
key: x509-store-1.6.2-D1ITMi7mZVrH6DgsUfztV9
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: 714d6b1da1eb885a092b5287c08d0e7c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-D1ITMi7mZVrH6DgsUfztV9
depends:
    asn1-encoding-0.9.5-A9izlTz6Ew2J4LAr7eelRX
    asn1-types-0.3.2-6x3pk8jPDOL1GdLO9ZccNW base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-DUE2wxQoCnxGJxqhoLxB9Z directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-9laM1ngk9s070ouI9TLAmW
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.2-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-store
version: 1.6.2
id: x509-store-1.6.2-FP7JqunYUjuDwvwkfEyyJA
key: x509-store-1.6.2-FP7JqunYUjuDwvwkfEyyJA
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory
abi: d294859814ca0e31af763ea28f724712
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-store-1.6.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/x509-store-1.6.2
hs-libraries: HSx509-store-1.6.2-FP7JqunYUjuDwvwkfEyyJA
depends:
    asn1-encoding-0.9.5-4zuNY5dpyCgHGZJcXAJva4
    asn1-types-0.3.2-KYu7pQLyIazKugAPAWEtdg base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-BghVPg0sVunAfXbG7gt71d directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.5-Da2tKOhQUlTA2oOdKTHYT4
haddock-interfaces: /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html: /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
